==> haskell-th-env-0.1.1-159.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-5HtAjUs1TCcDyfJcewAyxT
key:                  th-env-0.1.1-5HtAjUs1TCcDyfJcewAyxT
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  8da742258e0f94169c212f8a85d38ffe
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-5HtAjUs1TCcDyfJcewAyxT
depends:
    base-4.18.2.1 template-haskell-2.20.0.0
    th-compat-0.1.6-GpjIKGc0GPMFBEveh1mM8h

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-env-0.1.1-160-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-CrzTRfmfATkFykQrEKzCtH
key:                  th-env-0.1.1-CrzTRfmfATkFykQrEKzCtH
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  fdc0d6a6bd91a44a952b260e4c587259
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-CrzTRfmfATkFykQrEKzCtH
depends:
    base-4.18.2.1 template-haskell-2.20.0.0
    th-compat-0.1.6-KectvLb9yylAlpm8iQXOj

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
